# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Callbacks for additional setup tasks.

Add any additional tasks / setup here.  If a callback is used by mutliple
charms, consider refactoring it up to the jujubigdata library.
"""

from charmhelpers.core import hookenv
from charmhelpers.core import unitdata
from jujubigdata.relations import DataNode


def update_working_status():
    if unitdata.kv().get('charm.active', False):
        hookenv.status_set('maintenance', 'Updating configuration')
        return
    hookenv.status_set('maintenance', 'Setting up HDFS master')


def update_active_status():
    datanode = DataNode()
    if datanode.is_ready():
        hookenv.status_set('active', 'Ready (%s DataNodes)' % len(datanode.filtered_data()))
        unitdata.kv().set('charm.active', True)
    elif datanode.connected_units():
        hookenv.status_set('waiting', 'Waiting for compute slaves to provide DataNodes')
    else:
        hookenv.status_set('blocked', 'Waiting for relation to compute slaves')
